pub enum LogSeverity {
Trace,
Debug,
Info,
Warn,
Error,
}Expand description
Severity attached to a mark that may be projected as an OpenTelemetry log.
Variants
Trace
Fine-grained tracing information.
Debug
Diagnostic information useful during development.
Info
Normal informational event.
Warn
Potential problem that did not prevent the operation from continuing.
Error
Failure or error condition.
Implementations