pub struct NativeExecutorConfig {
pub worker_threads: usize,
}Expand description
Configuration for the executor owned by one exported native plugin.
Fields
worker_threads: usizeNumber of Tokio worker threads dedicated to the plugin.
Implementations
Sourceimpl NativeExecutorConfig
impl NativeExecutorConfig
Sourcepub fn with_component_config(
self,
plugin_config: &Map<String, Json>,
) -> Result<Self>
pub fn with_component_config( self, plugin_config: &Map<String, Json>, ) -> Result<Self>
Applies an optional component-local executor override.
Relay passes [plugins.dynamic.config.executor] as the executor
object in plugin_config. The only supported setting is the positive
integer worker_threads.