#[repr(C)]pub struct NemoRelayNativeLlmSanitizeResponseContext {
pub codec_kind: NemoRelayNativeLlmCodecKind,
pub codec_id: *const NemoRelayNativeString,
pub codec: *const NemoRelayNativeLlmResponseCodec,
}Expand description
Per-call response sanitizer context passed over the native ABI.
Fields
codec_kind: NemoRelayNativeLlmCodecKindDiscriminator for the active codec.
codec_id: *const NemoRelayNativeStringOptional borrowed codec identifier.
codec: *const NemoRelayNativeLlmResponseCodecBorrowed response codec capability, or null when no codec is active.