#[repr(C)]pub struct NemoRelayNativeLlmStreamV1 {
pub struct_size: usize,
pub user_data: *mut c_void,
pub next: Option<NemoRelayNativeLlmStreamPollFn>,
pub cancel: NemoRelayNativeLlmStreamCancelFn,
pub drop: NemoRelayNativeLlmStreamDropFn,
}Expand description
Native LLM JSON stream handle table.
Fields
struct_size: usizeSize of this struct as seen by the producer.
user_data: *mut c_voidStream state passed back to poll/cancel/drop callbacks.
next: Option<NemoRelayNativeLlmStreamPollFn>Polls the next stream chunk.
cancel: NemoRelayNativeLlmStreamCancelFnCancels an in-flight stream when a consumer stops before stream end.
drop: NemoRelayNativeLlmStreamDropFnDrops stream state after stream completion, error, or cancellation.