pub struct PendingMarkSpec {
pub name: String,
pub category: Option<EventCategory>,
pub category_profile: Option<CategoryProfile>,
pub data: Option<Value>,
pub metadata: Option<Value>,
}Expand description
Mark requested by middleware for materialization by a lifecycle owner.
The runtime assigns the parent UUID, event UUID, and timestamp when it materializes the mark at the appropriate lifecycle boundary.
Fields
name: StringHuman-readable mark name.
category: Option<EventCategory>Optional semantic category for the mark.
category_profile: Option<CategoryProfile>Optional category-specific typed fields.
data: Option<Value>Optional application payload attached to the mark.
metadata: Option<Value>Optional metadata attached to the mark.
Implementations
Sourceimpl PendingMarkSpec
impl PendingMarkSpec
Sourcepub fn builder() -> PendingMarkSpecBuilder
pub fn builder() -> PendingMarkSpecBuilder
Create a builder for building PendingMarkSpec.
On the builder, call .name(...), .category(...)(optional), .category_profile(...)(optional), .data(...)(optional), .metadata(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of PendingMarkSpec.