NemoRelayNativeLlmSanitizeRequestCb

Type Alias NemoRelayNativeLlmSanitizeRequestCb 

pub type NemoRelayNativeLlmSanitizeRequestCb = unsafe extern "C" fn(user_data: *mut c_void, request_json: *const NemoRelayNativeString, context: NemoRelayNativeLlmSanitizeRequestContext, out_request_json: *mut *mut NemoRelayNativeString) -> NemoRelayStatus;
Native LLM request sanitizer callback. Return a successful null output to omit the observability payload and annotation. request_json is borrowed, but may be written directly to out_request_json as a pass-through; the host releases an aliased input/output once. Any other non-null output must be host-allocated and transfers ownership to the host.