NemoRelayNativeLlmSanitizeResponseCb

Type Alias NemoRelayNativeLlmSanitizeResponseCb 

pub type NemoRelayNativeLlmSanitizeResponseCb = unsafe extern "C" fn(user_data: *mut c_void, payload_json: *const NemoRelayNativeString, context: NemoRelayNativeLlmSanitizeResponseContext, out_json: *mut *mut NemoRelayNativeString) -> NemoRelayStatus;
Native LLM response sanitizer callback. Return a successful null output to omit the observability payload and annotation. payload_json is borrowed, but may be written directly to out_json as a pass-through; the host releases an aliased input/output once. Any other non-null output must be host-allocated and transfers ownership to the host.