pub type NemoRelayNativeWithScopeStackCb = unsafe extern "C" fn(user_data: *mut c_void) -> NemoRelayStatus;Expand description
Native callback executed while a host scope stack is temporarily active.
pub type NemoRelayNativeWithScopeStackCb = unsafe extern "C" fn(user_data: *mut c_void) -> NemoRelayStatus;Native callback executed while a host scope stack is temporarily active.