pub unsafe fn export_plugin<P: NativePlugin>(
host: *const NemoRelayNativeHostApiV1,
out: *mut NemoRelayNativePluginV1,
plugin: P,
) -> NemoRelayStatusExpand description
Initializes a native plugin descriptor for a Rust SDK plugin value.
Safety
host must point to a valid NemoRelayNativeHostApiV1 for the duration
of the call, and out must point to writable memory for one
NemoRelayNativePluginV1 descriptor.