#[repr(C)]pub struct NemoRelayNativePluginV1 {
pub struct_size: usize,
pub plugin_kind: *mut NemoRelayNativeString,
pub allows_multiple_components: bool,
pub user_data: *mut c_void,
pub validate: Option<NemoRelayNativePluginValidateFn>,
pub register: Option<NemoRelayNativePluginRegisterFn>,
pub drop: NemoRelayNativePluginDropFn,
}Expand description
Versioned plugin descriptor returned by native plugin entry symbols.
Fields
struct_size: usizeSize of this struct as seen by the plugin.
plugin_kind: *mut NemoRelayNativeStringHost-owned plugin kind string.
allows_multiple_components: boolWhether this plugin kind supports multiple configured components.
user_data: *mut c_voidPlugin-owned state pointer passed to callbacks.
validate: Option<NemoRelayNativePluginValidateFn>Optional validation callback.
register: Option<NemoRelayNativePluginRegisterFn>Required registration callback.
drop: NemoRelayNativePluginDropFnOptional plugin-owned state destructor.