PluginRuntime

Struct PluginRuntime 

pub struct PluginRuntime { /* private fields */ }
Cloneable high-level runtime handle for host APIs available to native plugins.

Implementations

Source

impl PluginRuntime

pub fn new(host: &NemoRelayNativeHostApiV1) -> Self

Creates a runtime handle from the host ABI table.

pub fn host_api(&self) -> &NemoRelayNativeHostApiV1

Returns the underlying host ABI table.

pub fn current_scope(&self) -> Result<ScopeHandle<'_>>

Retrieves the current scope handle.

pub fn push_scope( &self, name: &str, scope_type: ScopeType, data: Option<&Json>, metadata: Option<&Json>, input: Option<&Json>, ) -> Result<ScopeHandle<'_>>

Pushes a scope and emits its start event.

pub fn pop_scope( &self, handle: &ScopeHandle<'_>, output: Option<&Json>, metadata: Option<&Json>, ) -> Result<()>

Pops a scope and emits its end event.

pub fn scope( &self, name: &str, scope_type: ScopeType, data: Option<&Json>, metadata: Option<&Json>, input: Option<&Json>, ) -> Result<ScopeGuard<'_>>

Opens a scope that is popped automatically when the guard is closed or dropped.

pub fn emit_mark( &self, name: &str, data: Option<&Json>, metadata: Option<&Json>, ) -> Result<()>

Emits a mark event under the current scope.

pub fn create_scope_stack(&self) -> Result<ScopeStack<'_>>

Creates a new independent scope stack.

pub fn capture_scope_stack_thread(&self) -> Result<ScopeStackBinding<'_>>

Captures the current thread-local scope-stack binding.

pub fn scope_stack_active(&self) -> bool

Returns whether the current context has an explicitly active scope stack.

pub fn bind_scope_stack_thread<'a>( &'a self, stack: &'a ScopeStack<'a>, ) -> Result<ThreadScopeStackGuard<'a>>

Binds stack to the current OS thread until the returned guard is dropped.