NemoRelayNativeAsyncLlmStreamOpenCb

Type Alias NemoRelayNativeAsyncLlmStreamOpenCb 

pub type NemoRelayNativeAsyncLlmStreamOpenCb = unsafe extern "C" fn(user_data: *mut c_void, stream: *const NemoRelayNativeLlmAsyncStream, error: *const NemoRelayNativeString);
Receives the result of asynchronously opening a downstream LLM stream.

Exactly one of stream and error is non-null. A non-null stream is an owned plugin reference and must be released exactly once.